@@ -1,7 +1,5 @@
 package DBIx::Class::DeploymentHandler::LogRouter;
-{
-  $DBIx::Class::DeploymentHandler::LogRouter::VERSION = '0.002210';
-}
+$DBIx::Class::DeploymentHandler::LogRouter::VERSION = '0.002211';
 use Moo;
 use DBIx::Class::DeploymentHandler::Logger;
 
@@ -32,24 +30,3 @@ sub before_import {}
 sub after_import {}
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-DBIx::Class::DeploymentHandler::LogRouter
-
-=head1 AUTHOR
-
-Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
