@@ -1,8 +1,5 @@
 package DBIx::Class::DeploymentHandler::Logger;
-{
-  $DBIx::Class::DeploymentHandler::Logger::VERSION = '0.002210';
-}
-
+$DBIx::Class::DeploymentHandler::Logger::VERSION = '0.002211';
 use warnings;
 use strict;
 
@@ -50,24 +47,3 @@ sub new {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-DBIx::Class::DeploymentHandler::Logger
-
-=head1 AUTHOR
-
-Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
